[![documentation](https://github.com/hcmlab/hcai-models/actions/workflows/documentation.yml/badge.svg)](https://github.com/hcmlab/hcai-models/actions/workflows/documentation.yml)

### Description
This repository contains code to make readly deploy pretrained machine learning model from the Chair for [Human-Centered Artificial Intelligence at the University of Augsburg](https://www.uni-augsburg.de/en/fakultaet/fai/informatik/prof/hcm/)

### Currently available Models

#### Image Models

| Model                                                             | Status | Weights  | Url
| :-------------                                                    |:------:| :-------------:| :-----|
| [EfficientNetB0](hcai_models/models/image/hcai_efficient_net)     | ✅     | imagenet | https://keras.io/api/applications/ |
| [EfficientNetB2](hcai_models/models/image/hcai_efficient_net)     | ✅     | imagenet | https://keras.io/api/applications/ |
| [EfficientNetB1](hcai_models/models/image/hcai_efficient_net)     | ✅     | imagenet | https://keras.io/api/applications/ |
| [EfficientNetB3](hcai_models/models/image/hcai_efficient_net)     | ✅     | imagenet | https://keras.io/api/applications/ |
| [EfficientNetB4](hcai_models/models/image/hcai_efficient_net)     | ✅     | imagenet | https://keras.io/api/applications/ |
| [EfficientNetB5](hcai_models/models/image/hcai_efficient_net)     | ✅     | imagenet | https://keras.io/api/applications/ |
| [EfficientNetB6](hcai_models/models/image/hcai_efficient_net)     | ✅     | imagenet | https://keras.io/api/applications/ |
| [EfficientNetB7](hcai_models/models/image/hcai_efficient_net)     | ✅     | imagenet | https://keras.io/api/applications/ |
| [InceptionV3](hcai_models/models/image/hcai_inception_v3)         | ✅     | imagenet | https://keras.io/api/applications/ |


